@@ -151,22 +151,32 @@ def upload_data_to_s3(s3_res, s3_bucket_name, s3_key, data, gzip_it, output_form
 		# json to parquet
 		elif output_format == 'parquet':
 			df = pd.DataFrame(data)
-			# default all data to string
-			table = pa.Table.from_pandas(df.fillna('').astype(str))
+
+			columns = list(df.columns)
 			# If datatypes are specified: Apply them here and add to pyarrow-table
 			# Else: Store everything as string and fill in empty strings for null-values
 			if 'dt' in kwargs:
 				for key, value in kwargs['dt'].items():
-					try:
-						if value == 'datetime':
-							df[key] = pd.to_datetime(df[key])
+					if key in columns:
+						try:
+							if value == 'datetime':
+								df[key] = pd.to_datetime(df[key])
+							elif value == 'leave_alone':
+								pass
+							else:
+								df[key] = df[key].astype(value)
+						except Exception as ex:
+							print('failed to set type', key, value)
+							print(str(ex))
+							pass
 						else:
-							df[key] = df[key].astype(value)
-					except Exception as ex:
-						print('failed to set type', key, value)
-						print(str(ex))
-						pass
-				table = pa.Table.from_pandas(df)
+							columns = [x for x in columns if x != key]
+			
+			# default rest of data to string
+			df[columns].fillna('').astype(str)
+
+			table = pa.Table.from_pandas(df)
+			
 			pq.write_table(table, b_io_buffer, coerce_timestamps='ms')
 			b_io_buffer.seek(0)
 		else:
